====================
Using csdmpy objects
====================

The `csdmpy` module is not just designed for deserializing and serializing
the `.csdf` or `.csdfe` files. It can also be used to create new datasets,
a feature that is most useful when converting datasets to CSDM compliant
files.

.. toctree::
    :maxdepth: 3

    dimension/generate/dimension_objects
    generating_dependent_variable_object
    generating_csdm_object
    add_dimension_object
    add_dependent_variable_object
